==> idoit-api-1.15.zip: src/classes/modules/api/install/isys_module_api_install.class.php <==
<?php

/**
 * i-doit api module installer.
 *
 * @package     i-doit
 * @subpackage  cmk2
 * @author      Selcuk Kekec <skekec@i-doit.com>
 * @version     1.10
 * @copyright   synetics GmbH
 * @license     http://www.i-doit.com/license
 * @since       i-doit 1.12
 */
class isys_module_api_install
{
    /**
     * Init method.
     *
     * @param   isys_component_database $mandatorDb
     * @param   isys_component_database $systemDb
     * @param   integer                 $moduleId
     * @param   string                  $type
     * @param   integer                 $tenantId
     */
    public static function init($mandatorDb, $systemDb, $moduleId, $type, $tenantId = null)
    {
        // Check whether tenantId is set:
        if (!empty($tenantId)) {
            if ($type === 'install') {
                self::install($mandatorDb, $systemDb, $moduleId, $type, $tenantId);
            } else if ($type === 'update') {
                self::update($mandatorDb, $systemDb, $moduleId, $type, $tenantId);
            }
        }
    }

    /**
     * Update
     *
     * @param      $mandatorDb
     * @param      $systemDb
     * @param      $moduleId
     * @param      $type
     * @param null $tenantId
     *
     * @throws isys_exception_dao
     */
    public static function update($mandatorDb, $systemDb, $moduleId, $type, $tenantId = null)
    {
        // Create tenant settings dao
        $tenantSettingsDao = new isys_component_dao_tenant_settings($systemDb, $tenantId);

        // Get tenant settings:
        $tenantSettings = $tenantSettingsDao->get_settings();

        if (!array_key_exists('api.validation', $tenantSettings)) {
            $tenantSettingsDao->set('api.validation', 1);
        }

        if (!array_key_exists('api.authenticated-users-only', $tenantSettings)) {
            $tenantSettingsDao->set('api.authenticated-users-only', 1);
        }

        if (!array_key_exists('api.status', $tenantSettings)) {
            $tenantSettingsDao->set('api.status', 1);
        }

        if (!array_key_exists('api.log-level', $tenantSettings)) {
            $tenantSettingsDao->set('api.log-level', 100);
        }

        $tenantSettingsDao->remove('api.use-auth');
        $tenantSettingsDao->remove('logging.system.api');

        // Create settings dao
        $systemSettingsDao = new isys_component_dao_settings($systemDb);
        $systemSettingsDao->remove('api.use-auth');
        $systemSettingsDao->remove('logging.system.api');
    }

    /**
     * Install
     *
     * @param isys_component_database $mandatorDb
     * @param isys_component_database $systemDb
     * @param                         $moduleId
     * @param                         $type
     * @param null                    $tenantId
     *
     * @throws isys_exception_dao
     */
    public static function install($mandatorDb, $systemDb, $moduleId, $type, $tenantId = null)
    {
        // Create tenant settings dao
        $tenantSettingsDao = new isys_component_dao_tenant_settings($systemDb, $tenantId);

        // Get tenant settings:
        $tenantSettings = $tenantSettingsDao->get_settings();


        $tenantSettingsDao->set('api.validation', 1);
        $tenantSettingsDao->set('api.authenticated-users-only', 1);
        $tenantSettingsDao->set('api.status', 1);
        $tenantSettingsDao->set('api.log-level', 100); // Set to warning

        $tenantSettingsDao->remove('api.use-auth');
        $tenantSettingsDao->remove('logging.system.api');

        // Create settings dao
        $systemSettingsDao = new isys_component_dao_settings($systemDb);
        $systemSettingsDao->remove('api.use-auth');
        $systemSettingsDao->remove('logging.system.api');

        // Check whether mandator has an api key
        $resource = $systemDb->query('SELECT isys_mandator__apikey FROM isys_mandator WHERE isys_mandator__id = ' . $systemDb->escape_string($tenantId) .
            ' AND (isys_mandator__apikey IS NULL OR isys_mandator__apikey = "")');

        if ($systemDb->num_rows($resource)) {
            // Create a new random apu key
            $apiKey = substr(base_convert(sha1(uniqid(mt_rand())), 16, 36), 0, 16);

            // Prepare update sql to insert new api key for mandator
            $sql = 'UPDATE isys_mandator SET isys_mandator__apikey = \'' . $systemDb->escape_string($apiKey) . '\' WHERE isys_mandator__id = ' .
                $systemDb->escape_string($tenantId);

            // Execute query
            $systemDb->query($sql) && $systemDb->commit();
        }
    }
}

==> idoit-api-1.16.zip: src/classes/modules/api/install/isys_module_api_install.class.php <==
<?php

/**
 * i-doit api module installer.
 *
 * @package     i-doit
 * @subpackage  cmk2
 * @author      Selcuk Kekec <skekec@i-doit.com>
 * @version     1.10
 * @copyright   synetics GmbH
 * @license     http://www.i-doit.com/license
 * @since       i-doit 1.12
 */
class isys_module_api_install
{
    /**
     * Init method.
     *
     * @param   isys_component_database $mandatorDb
     * @param   isys_component_database $systemDb
     * @param   integer                 $moduleId
     * @param   string                  $type
     * @param   integer                 $tenantId
     */
    public static function init($mandatorDb, $systemDb, $moduleId, $type, $tenantId = null)
    {
        // Check whether tenantId is set:
        if (!empty($tenantId)) {
            if ($type === 'install') {
                self::install($mandatorDb, $systemDb, $moduleId, $type, $tenantId);
            } else if ($type === 'update') {
                self::update($mandatorDb, $systemDb, $moduleId, $type, $tenantId);
            }
        }
    }

    /**
     * Update
     *
     * @param      $mandatorDb
     * @param      $systemDb
     * @param      $moduleId
     * @param      $type
     * @param null $tenantId
     *
     * @throws isys_exception_dao
     */
    public static function update($mandatorDb, $systemDb, $moduleId, $type, $tenantId = null)
    {
        // Create tenant settings dao
        $tenantSettingsDao = new isys_component_dao_tenant_settings($systemDb, $tenantId);
        $systemSettingsDao = new isys_component_dao_settings($systemDb);

        // Get tenant settings:
        $tenantSettings = $tenantSettingsDao->get_settings();
        $systemSettings = $systemSettingsDao->get_settings();

        if (!array_key_exists('api.validation', $tenantSettings)) {
            $tenantSettingsDao->set('api.validation', 1);
        }

        if (!array_key_exists('api.authenticated-users-only', $systemSettings)) {
            $systemSettingsDao->set('api.authenticated-users-only', 1);
        }

        if (!array_key_exists('api.status', $tenantSettings)) {
            $tenantSettingsDao->set('api.status', 1);
        }

        if (!array_key_exists('api.log-level', $tenantSettings)) {
            $tenantSettingsDao->set('api.log-level', 100);
        }

        $tenantSettingsDao->remove('api.use-auth');
        $tenantSettingsDao->remove('logging.system.api');

        // Create settings dao
        $systemSettingsDao->remove('api.use-auth');
        $systemSettingsDao->remove('logging.system.api');
    }

    /**
     * Install
     *
     * @param isys_component_database $mandatorDb
     * @param isys_component_database $systemDb
     * @param                         $moduleId
     * @param                         $type
     * @param null                    $tenantId
     *
     * @throws isys_exception_dao
     */
    public static function install($mandatorDb, $systemDb, $moduleId, $type, $tenantId = null)
    {
        // Create tenant settings dao
        $tenantSettingsDao = new isys_component_dao_tenant_settings($systemDb, $tenantId);

        // Get tenant settings:
        $tenantSettings = $tenantSettingsDao->get_settings();

        $tenantSettingsDao->set('api.validation', 1);
        $tenantSettingsDao->set('api.status', 1);
        $tenantSettingsDao->set('api.log-level', 100); // Set to warning
        $tenantSettingsDao->remove('api.use-auth');
        $tenantSettingsDao->remove('logging.system.api');

        // Create settings dao
        $systemSettingsDao = new isys_component_dao_settings($systemDb);
        $systemSettingsDao->set('api.authenticated-users-only', 1);
        $systemSettingsDao->remove('api.use-auth');
        $systemSettingsDao->remove('logging.system.api');

        // Check whether mandator has an api key
        $resource = $systemDb->query('SELECT isys_mandator__apikey FROM isys_mandator WHERE isys_mandator__id = ' . $systemDb->escape_string($tenantId) .
            ' AND (isys_mandator__apikey IS NULL OR isys_mandator__apikey = "")');

        if ($systemDb->num_rows($resource)) {
            // Create a new random apu key
            $apiKey = substr(base_convert(sha1(uniqid(mt_rand())), 16, 36), 0, 16);

            // Prepare update sql to insert new api key for mandator
            $sql = 'UPDATE isys_mandator SET isys_mandator__apikey = \'' . $systemDb->escape_string($apiKey) . '\' WHERE isys_mandator__id = ' .
                $systemDb->escape_string($tenantId);

            // Execute query
            $systemDb->query($sql) && $systemDb->commit();
        }
    }
}
